package mn.databank.pass.pass_mtx;

import androidx.annotation.NonNull;
import android.util.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import mn.databank.pass.pass_mtx.pass_mtx_android.PassMtxAndroid;

/** PassMtxPlugin */
public class PassMtxPlugin implements FlutterPlugin, MethodCallHandler {
  public static String TAG = "PassMtxPlugin.java";
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "pass_mtx");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    Log.i(TAG, "onMethodCall Method [" + call.method + "]");
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if (call.method.equals("getPassPing")) {
      result.success(PassMtxAndroid.PassPing());
    } else if (call.method.equals("getPassVersion")) {
      result.success(PassMtxAndroid.PassVersion());
    } else if (call.method.equals("getCard")) {
      final String user_id = call.argument("user_id");
      result.success(PassMtxAndroid.PassCardList(user_id));

    } else if (call.method.equals("passInit")) {
      final String app_id = call.argument("app_id");
      final String client_id = call.argument("client_id");
      final String private_pem = call.argument("private_pem");
      final String public_pem = call.argument("public_pem");
      result.success(PassMtxAndroid.PassInit(
        app_id,
        client_id,
        private_pem,
        public_pem
      ));
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

}
